@@ -73,6 +73,12 @@
 #define GPM_LINE_NUMBERS_DIR		GPM_PREFS_DIR "/editor/line_numbers"
 #define GPM_DISPLAY_LINE_NUMBERS 	GPM_LINE_NUMBERS_DIR "/display_line_numbers"
 
+#define GPM_CURRENT_LINE_DIR		GPM_PREFS_DIR "/editor/current_line"
+#define GPM_HIGHLIGHT_CURRENT_LINE 	GPM_CURRENT_LINE_DIR "/highlight_current_line"
+
+#define GPM_BRACKET_MATCHING_DIR	GPM_PREFS_DIR "/editor/bracket_matching"
+#define GPM_BRACKET_MATCHING		GPM_BRACKET_MATCHING_DIR "/bracket_matching"
+
 #define GPM_RIGHT_MARGIN_DIR		GPM_PREFS_DIR "/editor/right_margin"
 #define GPM_DISPLAY_RIGHT_MARGIN	GPM_RIGHT_MARGIN_DIR "/display_right_margin"
 #define GPM_RIGHT_MARGIN_POSITION	GPM_RIGHT_MARGIN_DIR "/right_margin_position"
@@ -86,8 +92,8 @@
 #define GPM_STATUSBAR_DIR		GPM_PREFS_DIR "/ui/statusbar"
 #define GPM_STATUSBAR_VISIBLE		GPM_STATUSBAR_DIR "/statusbar_visible"
 
-#define GRM_RECENTS_DIR			GPM_PREFS_DIR "/ui/recents"
-#define GPM_MAX_RECENTS			GRM_RECENTS_DIR "/max_recents"
+#define GPM_RECENTS_DIR			GPM_PREFS_DIR "/ui/recents"
+#define GPM_MAX_RECENTS			GPM_RECENTS_DIR "/max_recents"
 
 /* Print */
 #define GPM_PRINT_PAGE_DIR		GPM_PREFS_DIR "/print/page"
@@ -98,8 +104,11 @@
 
 #define GPM_PRINT_FONT_DIR		GPM_PREFS_DIR "/print/fonts"
 #define GPM_PRINT_FONT_BODY		GPM_PRINT_FONT_DIR "/print_font_body"
+#define GPM_PRINT_FONT_BODY_PANGO	GPM_PRINT_FONT_DIR "/print_font_body_pango"
 #define GPM_PRINT_FONT_HEADER		GPM_PRINT_FONT_DIR "/print_font_header"
+#define GPM_PRINT_FONT_HEADER_PANGO	GPM_PRINT_FONT_DIR "/print_font_header_pango"
 #define GPM_PRINT_FONT_NUMBERS		GPM_PRINT_FONT_DIR "/print_font_numbers"
+#define GPM_PRINT_FONT_NUMBERS_PANGO	GPM_PRINT_FONT_DIR "/print_font_numbers_pango"
 
 #define GPM_WINDOW_DIR			"/gedit-2/window"
 #define GPM_WINDOW_STATE		GPM_WINDOW_DIR "/state"
@@ -132,8 +141,6 @@
 #define GPM_DEFAULT_AUTO_SAVE		0 /* FALSE */
 #define GPM_DEFAULT_AUTO_SAVE_INTERVAL	10 /* minutes */
 
-#define GPM_DEFAULT_SAVE_ENCODING	(const gchar*) "GEDIT_SAVE_ALWAYS_UTF8"
-
 #define GPM_DEFAULT_UNDO_ACTIONS_LIMIT	25 /* actions */
 
 #define GPM_DEFAULT_WRAP_MODE		"GTK_WRAP_WORD"
@@ -158,9 +165,9 @@
 #define GPM_DEFAULT_PRINT_WRAP_MODE	"GTK_WRAP_WORD"
 #define GPM_DEFAULT_PRINT_LINE_NUMBERS	0 /* No numbers */
 
-#define GPM_DEFAULT_PRINT_FONT_BODY 	(const gchar*) "Monospace Regular 9"
-#define GPM_DEFAULT_PRINT_FONT_HEADER	(const gchar*) "Sans Regular 11"
-#define GPM_DEFAULT_PRINT_FONT_NUMBERS	(const gchar*) "Sans Regular 8"
+#define GPM_DEFAULT_PRINT_FONT_BODY_PANGO 	(const gchar*) "Monospace 9"
+#define GPM_DEFAULT_PRINT_FONT_HEADER_PANGO	(const gchar*) "Sans 11"
+#define GPM_DEFAULT_PRINT_FONT_NUMBERS_PANGO	(const gchar*) "Sans 8"
 
 #define GPM_DEFAULT_MAX_RECENTS		5
 
@@ -172,6 +179,10 @@
 #define GPM_DEFAULT_WINDOW_WIDTH_STR	"650"
 #define GPM_DEFAULT_WINDOW_HEIGHT_STR	"500"
 
+#define GPM_DEFAULT_HIGHLIGHT_CURRENT_LINE  1 /* TRUE */
+
+#define GPM_DEFAULT_BRACKET_MATCHING	  0 /* FALSE */
+
 #define GPM_DEFAULT_DISPLAY_RIGHT_MARGIN  0 /* FALSE */
 #define GPM_DEFAULT_RIGHT_MARGIN_POSITION 80
 
@@ -343,6 +354,16 @@ GSList			*gedit_prefs_manager_get_shown_in_menu_encodings (void);
 void			 gedit_prefs_manager_set_shown_in_menu_encodings (const GSList *encs);
 gboolean 		 gedit_prefs_manager_shown_in_menu_encodings_can_set (void);
 
+/* Highlight current line */
+gboolean		 gedit_prefs_manager_get_highlight_current_line	(void);
+void			 gedit_prefs_manager_set_highlight_current_line	(gboolean hl);
+gboolean		 gedit_prefs_manager_highlight_current_line_can_set (void);
+
+/* Highlight matching bracket */
+gboolean		 gedit_prefs_manager_get_bracket_matching	(void);
+void			 gedit_prefs_manager_set_bracket_matching	(gboolean bm);
+gboolean		 gedit_prefs_manager_bracket_matching_can_set (void);
+
 /* Display right margin */
 gboolean		 gedit_prefs_manager_get_display_right_margin	(void);
 void			 gedit_prefs_manager_set_display_right_margin	(gboolean drm);
